
#pragma comment(lib, "gdiplus.lib")
#pragma comment(lib, "user32.lib")

#include <windows.h>
#include <gdiplus.h>

using namespace Gdiplus;

typedef struct {
   DWORD  mVersion;
   HWND   mHwnd;
   BOOL   mKeep;
} LOADINFO;

GdiplusStartupInput gdiplusStartupInput;
ULONG_PTR gdiplusToken;

int GetEncoderClsid(const WCHAR* format, CLSID* pClsid) {
	UINT  num = 0;
	UINT  size = 0;

	ImageCodecInfo* pImageCodecInfo = NULL;

	GetImageEncodersSize(&num, &size);
	if(size == 0)
	return -1;

	pImageCodecInfo = (ImageCodecInfo*)(malloc(size));
	if(pImageCodecInfo == NULL)
	return -1;

	GetImageEncoders(num, size, pImageCodecInfo);

	for(UINT j = 0; j < num; ++j) {
		if (wcscmp(pImageCodecInfo[j].MimeType, format) == 0) {
			*pClsid = pImageCodecInfo[j].Clsid;
			free(pImageCodecInfo);
			return j;
		}
	}
	free(pImageCodecInfo);
	return -1;  // Failure
}

extern "C" {
	int WINAPI LoadDll(LOADINFO *mIRC) {
		GdiplusStartup(&gdiplusToken, &gdiplusStartupInput, NULL);
		return 3;
	}

	int WINAPI UnloadDll(int timeout) {
		if (timeout == 1)
			return 0;

		GdiplusShutdown(gdiplusToken);
		return 1;
	};

	int WINAPI takess(HWND,HWND,char *data,char*,BOOL,BOOL) {
		int nScreenWidth = GetSystemMetrics(SM_CXSCREEN);
		int nScreenHeight = GetSystemMetrics(SM_CYSCREEN);
		HWND hDesktopWnd = GetDesktopWindow();
		HDC hDesktopDC = GetDC(hDesktopWnd);
		HDC hCaptureDC = CreateCompatibleDC(hDesktopDC);
		HBITMAP hCaptureBitmap = CreateCompatibleBitmap(hDesktopDC, 
							nScreenWidth, nScreenHeight);
		SelectObject(hCaptureDC, hCaptureBitmap); 
		BitBlt(hCaptureDC, 0, 0, nScreenWidth, nScreenHeight,
		   hDesktopDC, 0, 0, SRCCOPY|CAPTUREBLT); 


		Bitmap b(hCaptureBitmap, NULL);
		CLSID encoderClsid;
		GetEncoderClsid(L"image/jpeg", &encoderClsid);

		WCHAR wszPath[MAX_PATH+1];

		MultiByteToWideChar(CP_ACP, 0, data + 4, strlen(data + 4)+1,
		wszPath, sizeof(wszPath)/sizeof(*wszPath)); 

		EncoderParameters eps;
		eps.Count = 1;
		eps.Parameter[0].Guid = EncoderQuality;
		eps.Parameter[0].Type = EncoderParameterValueTypeLong;
		eps.Parameter[0].NumberOfValues = 1;
		*(data + 3) = '\0';
		int quality = atoi(data);
		eps.Parameter[0].Value = &quality;
		b.Save(wszPath, &encoderClsid, &eps);

		ReleaseDC(hDesktopWnd,hDesktopDC);
		DeleteDC(hCaptureDC);
		DeleteObject(hCaptureBitmap);
		lstrcpy(data, "k");
		return 3;
	}
}

